package Pcore::App::API::Backend::Remote;

use Pcore -class, -res;

with qw[Pcore::App::API];

sub init ($self) {
    return res 200;
}

1;
__END__
=pod

=encoding utf8

=head1 NAME

Pcore::App::API::Backend::Remote

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 ATTRIBUTES

=head1 METHODS

=head1 SEE ALSO

=cut
